%define nspr_name       nspr
%define nspr_version    4.6
%define nss_name        nss
%define nss_version     3.11
%define svrcore_name    svrcore
%define svrcore_version 1.4.0.18

%define major           6
%define minor           0
%define submin          7
%define libsuffix       %{major}0

Summary:          Mozilla LDAP C SDK
Name:             mozldap
Version:          %{major}.%{minor}.%{submin}
Release:          %mkrel 18
License:          MPLv1.1 or GPLv2+ or LGPLv2+
Group:            System/Libraries
URL:              https://www.mozilla.org/directory/csdk.html
Source0:          ftp://ftp.mozilla.org/pub/mozilla.org/directory/c-sdk/releases/v%{version}/src/%{name}-%{version}.tar.gz
Patch0:           mozldap-6.0.7-perl-escape.patch
Patch1:           mozldap-6.0.7-gcc14.patch
BuildRequires:    %{nspr_name}-devel >= %{nspr_version}
BuildRequires:    %{nss_name}-devel >= %{nss_version}
BuildRequires:    %{svrcore_name}-devel >= 1:%{svrcore_version}
BuildRequires:    gcc-c++
BuildRequires:    pkgconfig(libsasl2)

%description
The Mozilla LDAP C SDK is a set of libraries that
allow applications to communicate with LDAP directory
servers.  These libraries are derived from the University
of Michigan and Netscape LDAP libraries.  They use Mozilla
NSPR and NSS for crypto.


%package tools
Summary:          Tools for the Mozilla LDAP C SDK
Group:            System/Libraries 
Requires:         %{name} = %{version}-%{release}
BuildRequires:    %{nspr_name}-devel >= %{nspr_version}
BuildRequires:    %{nss_name}-devel >= %{nss_version}
BuildRequires:    %{svrcore_name}-devel >= 1:%{svrcore_version}

%description tools
The mozldap-tools package provides the ldapsearch,
ldapmodify, and ldapdelete tools that use the
Mozilla LDAP C SDK libraries.


%package devel
Summary:          Development libraries and examples for Mozilla LDAP C SDK
Group:            Development/C
Requires:         %{name} = %{version}-%{release}

%description devel
Header and Library files for doing development with the Mozilla LDAP C SDK

%prep
%autosetup -p1

%build
cd c-sdk

%configure \
%ifarch x86_64
    --enable-64bit \
%endif
    --with-sasl \
    --with-system-nss \
    --with-system-nspr \
    --with-system-svrcore \
    --enable-clu \
    --enable-optimize \
    --disable-debug

# Enable compiler optimizations and disable debugging code
BUILD_OPT=1
export BUILD_OPT

# Generate symbolic info for debuggers
XCFLAGS="$RPM_OPT_FLAGS"
export XCFLAGS

PKG_CONFIG_ALLOW_SYSTEM_LIBS=1
PKG_CONFIG_ALLOW_SYSTEM_CFLAGS=1

export PKG_CONFIG_ALLOW_SYSTEM_LIBS
export PKG_CONFIG_ALLOW_SYSTEM_CFLAGS

make \
%ifarch x86_64
    USE_64=1
%endif

%install
# Set up our package file
%{__mkdir_p} %{buildroot}%{_libdir}/pkgconfig
%{__cat} c-sdk/mozldap.pc.in \
    | sed -e "s,%%libdir%%,%{_libdir},g" \
          -e "s,%%prefix%%,%{_prefix},g" \
          -e "s,%%major%%,%{major},g" \
          -e "s,%%minor%%,%{minor},g" \
          -e "s,%%submin%%,%{submin},g" \
          -e "s,%%libsuffix%%,%{libsuffix},g" \
          -e "s,%%bindir%%,%{_libdir}/%{name},g" \
          -e "s,%%exec_prefix%%,%{_prefix},g" \
          -e "s,%%includedir%%,%{_includedir}/%{name},g" \
          -e "s,%%NSPR_VERSION%%,%{nspr_version},g" \
          -e "s,%%NSS_VERSION%%,%{nss_version},g" \
          -e "s,%%SVRCORE_VERSION%%,%{svrcore_version},g" \
          -e "s,%%MOZLDAP_VERSION%%,%{version},g" \
    > %{buildroot}%{_libdir}/pkgconfig/%{name}.pc

# There is no make install target so we'll do it ourselves.

%{__mkdir_p} %{buildroot}%{_includedir}/%{name}
%{__mkdir_p} %{buildroot}%{_libdir}/%{name}
echo $(pwd)

# Copy the binary libraries we want
for file in libssldap%{libsuffix}.so libprldap%{libsuffix}.so libldap%{libsuffix}.so libldif%{libsuffix}.so
do
  %{__install} -m 755 ../dist/lib/$file %{buildroot}%{_libdir}
done

# Copy the binaries we want
for file in ldapsearch ldapmodify ldapdelete ldapcmp ldapcompare ldappasswd
do
  %{__install} -m 755 ../dist/bin/$file %{buildroot}%{_libdir}/%{name}
done

# Copy the include files
for file in ../dist/public/ldap/*.h
do
  %{__install} -p -m 644 $file %{buildroot}%{_includedir}/%{name}
done

# Copy the developer files
%{__mkdir_p} %{buildroot}%{_datadir}/%{name}
cp -r c-sdk/ldap/examples %{buildroot}%{_datadir}/%{name}
%{__mkdir_p} %{buildroot}%{_datadir}/%{name}/etc
%{__install} -m 644 c-sdk/ldap/examples/xmplflt.conf %{buildroot}%{_datadir}/%{name}/etc
%{__install} -m 644 c-sdk/ldap/libraries/libldap/ldaptemplates.conf %{buildroot}%{_datadir}/%{name}/etc
%{__install} -m 644 c-sdk/ldap/libraries/libldap/ldapfilter.conf %{buildroot}%{_datadir}/%{name}/etc
%{__install} -m 644 c-sdk/ldap/libraries/libldap/ldapsearchprefs.conf %{buildroot}%{_datadir}/%{name}/etc

%files
%doc c-sdk/README.rpm
%{_libdir}/libssldap*.so
%{_libdir}/libprldap*.so
%{_libdir}/libldap*.so
%{_libdir}/libldif*.so

%files tools
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/ldapsearch
%{_libdir}/%{name}/ldapmodify
%{_libdir}/%{name}/ldapdelete
%{_libdir}/%{name}/ldapcmp
%{_libdir}/%{name}/ldapcompare
%{_libdir}/%{name}/ldappasswd

%files devel
%{_libdir}/pkgconfig/%{name}.pc
%{_includedir}/%{name}/
%{_datadir}/%{name}/




%changelog
* Sun Jun 29 2025 umeabot <umeabot> 6.0.7-18.mga10
+ Revision: 2229004
- Mageia 10 Mass Rebuild

* Thu Oct 17 2024 daviddavid <daviddavid> 6.0.7-17.mga10
+ Revision: 2107734
- fix build with GCC 14

* Tue Mar 29 2022 umeabot <umeabot> 6.0.7-16.mga9
+ Revision: 1833020
- Mageia 9 Mass Rebuild

* Sat Jan 09 2021 luigiwalser <luigiwalser> 6.0.7-15.mga8
+ Revision: 1669967
- try calling autoreconf to fix build
- remove previous build fix which breaks build
+ danf <danf>
- Switch URLs from http: to https:

* Tue Feb 18 2020 umeabot <umeabot> 6.0.7-14.mga8
+ Revision: 1538600
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%setup_compile_flags

* Sun Nov 24 2019 wally <wally> 6.0.7-13.mga8
+ Revision: 1462605
- build with latest svrcore merged into 389-ds-base

* Sun Sep 23 2018 umeabot <umeabot> 6.0.7-12.mga7
+ Revision: 1299609
- Mageia 7 Mass Rebuild

* Wed Aug 01 2018 pterjan <pterjan> 6.0.7-11.mga7
+ Revision: 1246539
- Drop the build patch, no longer needed
- Fix build
- Fix build failure with new perl and for aarch64

* Tue May 31 2016 spuhler <spuhler> 6.0.7-10.mga6
+ Revision: 1019646
-re-build with updated svrcore-devel

* Fri Feb 05 2016 umeabot <umeabot> 6.0.7-9.mga6
+ Revision: 936392
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 6.0.7-8.mga5
+ Revision: 743503
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 6.0.7-7.mga5
+ Revision: 727349
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 6.0.7-6.mga5
+ Revision: 682619
- Mageia 5 Mass Rebuild

* Thu Aug 14 2014 wally <wally> 6.0.7-5.mga5
+ Revision: 662523
- fix devel pkg group
- drop unneeded requires which are already pulled via lib deps
- drop unneeded post/postun scripts
- drop unneeded requires from devel pkg
- build with our compiler/linker flags

* Sat Oct 19 2013 umeabot <umeabot> 6.0.7-4.mga4
+ Revision: 533220
- Mageia 4 Mass Rebuild

* Tue Aug 27 2013 luigiwalser <luigiwalser> 6.0.7-3.mga4
+ Revision: 472080
- rebuild for cyrus-sasl

* Sat Jan 12 2013 umeabot <umeabot> 6.0.7-2.mga3
+ Revision: 360320
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Dec 06 2012 spuhler <spuhler> 6.0.7-1.mga3
+ Revision: 327513
- upgrade to 6.0.7
  lots of spec changes because of package structure

* Fri Aug 17 2012 spuhler <spuhler> 6.0.5-1.mga3
+ Revision: 281753
- imported package mozldap

